# This file is generated by SciPy's build process
# It contains system_info results at the time of building this package.
from enum import Enum

__all__ = ["show"]
_built_with_meson = True


class DisplayModes(Enum):
    stdout = "stdout"
    dicts = "dicts"


def _cleanup(d):
    """
    Removes empty values in a `dict` recursively
    This ensures we remove values that Meson could not provide to CONFIG
    """
    if isinstance(d, dict):
        return { k: _cleanup(v) for k, v in d.items() if v != '' and _cleanup(v) != '' }
    else:
        return d


CONFIG = _cleanup(
    {
        "Compilers": {
            "c": {
                "name": "gcc",
                "linker": r"ld.bfd",
                "version": "14.2.0",
                "commands": r"cc",
                "args": r"-O2, -g, -pipe, -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3, -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1, -fstack-protector-strong, -fomit-frame-pointer, -m32, -march=i686, -msse2, -mtune=generic, -mfpmath=sse, -mstackrealign, -fasynchronous-unwind-tables, -fstack-clash-protection, -fcf-protection=full",
                "linker args": r"-fPIE, -O2, -g, -pipe, -Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3, -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1, -fstack-protector-strong, -fomit-frame-pointer, -m32, -march=i686, -msse2, -mtune=generic, -mfpmath=sse, -mstackrealign, -fasynchronous-unwind-tables, -fstack-clash-protection, -fcf-protection=full",
            },
            "cython": {
                "name": r"cython",
                "linker": r"cython",
                "version": r"3.0.11",
                "commands": r"cython",
                "args": r"",
                "linker args": r"",
            },
            "c++": {
                "name": "gcc",
                "linker": r"ld.bfd",
                "version": "14.2.0",
                "commands": r"c++",
                "args": r"",
                "linker args": r"-fPIE",
            },
            "fortran": {
                "name": "gcc",
                "linker": r"ld.bfd",
                "version": "14.2.0",
                "commands": r"gfortran",
                "args": r"",
                "linker args": r"-fPIE",
            },
            "pythran": {
                "version": r"",
                "include directory": r""
            },
        },
        "Machine Information": {
            "host": {
                "cpu": r"i686",
                "family": r"x86",
                "endian": r"little",
                "system": r"linux",
            },
            "build": {
                "cpu": r"i686",
                "family": r"x86",
                "endian": r"little",
                "system": r"linux",
            },
            "cross-compiled": bool("False".lower().replace('false', '')),
        },
        "Build Dependencies": {
            "blas": {
                "name": "blas",
                "found": bool("True".lower().replace('false', '')),
                "version": "3.12.0",
                "detection method": "pkgconfig",
                "include directory": r"/usr/include",
                "lib directory": r"/usr/lib",
                "openblas configuration": r"unknown",
                "pc file directory": r"/usr/lib/pkgconfig",
            },
            "lapack": {
                "name": "lapack",
                "found": bool("True".lower().replace('false', '')),
                "version": "3.12.0",
                "detection method": "pkgconfig",
                "include directory": r"/usr/include",
                "lib directory": r"/usr/lib",
                "openblas configuration": r"unknown",
                "pc file directory": r"/usr/lib/pkgconfig",
            },
            "pybind11": {
                "name": "pybind11",
                "version": "2.12.0",
                "detection method": "pkgconfig",
                "include directory": r"/include",
            },
        },
        "Python Information": {
            "path": r"/usr/bin/python3",
            "version": "3.12",
        },
    }
)


def _check_pyyaml():
    import yaml

    return yaml


def show(mode=DisplayModes.stdout.value):
    """
    Show libraries and system information on which SciPy was built
    and is being used

    Parameters
    ----------
    mode : {`'stdout'`, `'dicts'`}, optional.
        Indicates how to display the config information.
        `'stdout'` prints to console, `'dicts'` returns a dictionary
        of the configuration.

    Returns
    -------
    out : {`dict`, `None`}
        If mode is `'dicts'`, a dict is returned, else None

    Notes
    -----
    1. The `'stdout'` mode will give more readable
       output if ``pyyaml`` is installed

    """
    if mode == DisplayModes.stdout.value:
        try:  # Non-standard library, check import
            yaml = _check_pyyaml()

            print(yaml.dump(CONFIG))
        except ModuleNotFoundError:
            import warnings
            import json

            warnings.warn("Install `pyyaml` for better output", stacklevel=1)
            print(json.dumps(CONFIG, indent=2))
    elif mode == DisplayModes.dicts.value:
        return CONFIG
    else:
        raise AttributeError(
            f"Invalid `mode`, use one of: {', '.join([e.value for e in DisplayModes])}"
        )
